@@ -22,6 +22,8 @@ from synalinks.src.ops.operation import Operation
 from synalinks.src.saving.synalinks_saveable import SynalinksSaveable
 from synalinks.src.utils import python_utils
 from synalinks.src.utils import tracking
+from synalinks.src.utils.naming import auto_name
+from synalinks.src.utils.async_utils import run_maybe_nested
 
 if backend.backend() == "pydantic":
     from synalinks.src.backend.pydantic.module import PydanticModule as BackendModule
@@ -285,14 +287,14 @@ class Module(BackendModule, Operation, SynalinksSaveable):
         """
         if config:
             if "input_schema" in config:
-                asyncio.get_event_loop().run_until_complete(
+                run_maybe_nested(
                     self.build(backend.SymbolicDataModel(schema=config["input_schema"]))
                 )
             elif "schemas_dict" in config:
                 symbolic_inputs = {}
                 for key, schema in config["schemas_dict"].items():
                     symbolic_inputs[key] = backend.SymbolicDataModel(schema=schema)
-                asyncio.get_event_loop().run_until_complete(self.build(**symbolic_inputs))
+                run_maybe_nested(self.build(**symbolic_inputs))
             self.built = True
 
     def _obj_type(self):
@@ -757,6 +759,14 @@ class Module(BackendModule, Operation, SynalinksSaveable):
                 )
         self.built = True
 
+    def clone(self, name=None):
+        clone = self.from_config(self.get_config())
+        if name:
+            clone.name = name
+        else:
+            clone.name = auto_name(self.name)
+        return clone
+
 
 def is_json_data_model_or_symbolic_data_model(x, allow_none=False):
     if allow_none and x is None:
